@@ -2,7 +2,7 @@
 /*
   clock.h: Clock and timefunctions for Gnome Predict.
 
-  Copyright (C)  2001-2003  Alexandru Csete.
+  Copyright (C)  2001-2005  Alexandru Csete.
 
   Authors:  Alexandru Csete <csete@users.sourceforge.net>
 
@@ -31,8 +31,12 @@
 #ifndef CLOCK_H
 #define CLOCK_H
 
-gint clock_timer_callback( gpointer );
-void clock_timer_start( void );
-void clock_timer_stop( void );
+#define CLOCK_SHOW_LOCAL_TIME_PATH "/apps/gpredict/showlocaltime"
+#define CLOCK_TIME_FORMAT_PATH     "/apps/gpredict/timeformat"
+#define CLOCK_TIME_FORMAT_DEFAULT  "%c"  /* local date and time representation */
+
+gint clock_timer_callback (gpointer);
+void clock_timer_start    (void);
+void clock_timer_stop     (void);
 
 #endif
