@@ -550,6 +550,10 @@ Calc (guint i , gdouble dnum)
 
 
 	if ( ( i >= 0 ) && ( i < SAT_MAX ) ) {
+		/* store previous elevation */
+		sat_table[i]->prevel = sat_table[i]->el;
+
+		/* calculate new parameters */
 		sat_table[i]->age = dnum-sat_table[i]->epoch;
 		sat_table[i]->o = DEG2RAD*(sat_table[i]->raan-(sat_table[i]->age)*
 					   sat_table[i]->k2*sat_table[i]->c1);
