@@ -28,6 +28,8 @@
 	  USA
 */
 
+#if defined (HAVE_HAMLIB)
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -769,3 +771,5 @@ satpref_rig_test_cb        (GtkWidget *button, gpointer clist)
 	   radio.
 	*/
 }
+
+#endif /* (HAVE_HAMLIB) */
