@@ -32,10 +32,14 @@
 #ifndef SATPREF_RIG_H
 #define SATPREF_RIG_H
 
+#if defined (HAVE_HAMLIB)
+
 GtkWidget *satpref_rig_create (void);
 void       satpref_rig_close  (void);
 void       satpref_rig_apply  (void);
 void       satpref_rig_cancel (void);
 void       satpref_rig_help   (void);
 
+#endif /* (HAVE_HAMLIB) */
+
 #endif
