@@ -28,6 +28,8 @@
 	  USA
 */
 
+#if defined (HAVE_HAMLIB)
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -768,3 +770,6 @@ satpref_rot_test_cb        (GtkWidget *button, gpointer clist)
 	   radio.
 	*/
 }
+
+
+#endif /* (HAVE_HAMLIB) */
