@@ -32,10 +32,14 @@
 #ifndef SATPREF_ROT_H
 #define SATPREF_ROT_H
 
+#if defined (HAVE_HAMLIB)
+
 GtkWidget *satpref_rot_create (void);
 void       satpref_rot_close  (void);
 void       satpref_rot_apply  (void);
 void       satpref_rot_cancel (void);
 void       satpref_rot_help   (void);
 
+#endif /* (HAVE_HAMLIB) */
+
 #endif
